@@ -10,14 +10,12 @@
 #include <glib/gi18n-lib.h>
 
 #include "e-ews-folder.h"
-#include "e-ews-message.h"
+#include "e-ews-request.h"
 #include "e-ews-enumtypes.h"
 #include "ews-errors.h"
 #include "e-source-ews-folder.h"
 #include "camel-ews-settings.h"
 
-G_DEFINE_TYPE (EEwsFolder, e_ews_folder, G_TYPE_OBJECT)
-
 struct _EEwsFolderPrivate {
 	GError *error;
 	gchar *name;
@@ -35,6 +33,8 @@ struct _EEwsFolderPrivate {
 	gboolean is_hidden;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (EEwsFolder, e_ews_folder, G_TYPE_OBJECT)
+
 static void
 e_ews_folder_dispose (GObject *object)
 {
@@ -82,8 +82,6 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (EEwsFolderPrivate));
-
 	object_class->dispose = e_ews_folder_dispose;
 	object_class->finalize = e_ews_folder_finalize;
 }
@@ -91,7 +89,7 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 static void
 e_ews_folder_init (EEwsFolder *folder)
 {
-	folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (folder, E_TYPE_EWS_FOLDER, EEwsFolderPrivate);
+	folder->priv = e_ews_folder_get_instance_private (folder);
 	folder->priv->error = NULL;
 	folder->priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
 	folder->priv->foreign = FALSE;
@@ -204,7 +202,7 @@ e_ews_folder_set_from_soap_parameter (EEwsFolder *folder,
 			if (prop_tag && g_ascii_strcasecmp (prop_tag, "0xe08") == 0) {
 				subparam1 = e_soap_parameter_get_first_child_by_name (subparam, "Value");
 				if (subparam1)
-					priv->size = e_soap_parameter_get_int_value (subparam1);
+					priv->size = e_soap_parameter_get_uint64_value (subparam1);
 			} else if (prop_tag && g_ascii_strcasecmp (prop_tag, "0x10f4") == 0) { /* PidTagAttributeHidden */
 				subparam1 = e_soap_parameter_get_first_child_by_name (subparam, "Value");
 				if (subparam1) {
@@ -365,29 +363,29 @@ e_ews_folder_id_is_equal (const EwsFolderId *a,
 }
 
 void
-e_ews_folder_id_append_to_msg (ESoapMessage *msg,
-			       const gchar *email,
-			       const EwsFolderId *fid)
+e_ews_folder_id_append_to_request (ESoapRequest *request,
+				   const gchar *email,
+				   const EwsFolderId *fid)
 {
-	g_return_if_fail (msg != NULL);
+	g_return_if_fail (request != NULL);
 	g_return_if_fail (fid != NULL);
 
 	if (fid->is_distinguished_id)
-		e_soap_message_start_element (msg, "DistinguishedFolderId", NULL, NULL);
+		e_soap_request_start_element (request, "DistinguishedFolderId", NULL, NULL);
 	else
-		e_soap_message_start_element (msg, "FolderId", NULL, NULL);
+		e_soap_request_start_element (request, "FolderId", NULL, NULL);
 
-	e_soap_message_add_attribute (msg, "Id", fid->id, NULL, NULL);
+	e_soap_request_add_attribute (request, "Id", fid->id, NULL, NULL);
 	if (fid->change_key)
-		e_soap_message_add_attribute (msg, "ChangeKey", fid->change_key, NULL, NULL);
+		e_soap_request_add_attribute (request, "ChangeKey", fid->change_key, NULL, NULL);
 
 	if (fid->is_distinguished_id && email) {
-		e_soap_message_start_element (msg, "Mailbox", NULL, NULL);
-		e_ews_message_write_string_parameter (msg, "EmailAddress", NULL, email);
-		e_soap_message_end_element (msg);
+		e_soap_request_start_element (request, "Mailbox", NULL, NULL);
+		e_ews_request_write_string_parameter (request, "EmailAddress", NULL, email);
+		e_soap_request_end_element (request);
 	}
 
-	e_soap_message_end_element (msg);
+	e_soap_request_end_element (request);
 }
 
 const gchar *
@@ -848,8 +846,7 @@ e_ews_folder_utils_add_as_esource (ESourceRegistry *pregistry,
 }
 
 gboolean
-e_ews_folder_utils_remove_as_esource (ESourceRegistry *pregistry,
-                                      const gchar *master_hosturl,
+e_ews_folder_utils_remove_as_esource (const gchar *master_hosturl,
                                       const gchar *master_username,
                                       const gchar *folder_id,
                                       GCancellable *cancellable,
@@ -860,12 +857,9 @@ e_ews_folder_utils_remove_as_esource (ESourceRegistry *pregistry,
 	GList *sources;
 	gboolean res = TRUE;
 
-	registry = pregistry;
-	if (!registry) {
-		registry = e_source_registry_new_sync (cancellable, perror);
-		if (!registry)
-			return FALSE;
-	}
+	registry = e_source_registry_new_sync (cancellable, perror);
+	if (!registry)
+		return FALSE;
 
 	sources = e_source_registry_list_sources (registry, NULL);
 	source = e_ews_folder_utils_get_source_for_folder (sources, master_hosturl, master_username, folder_id);
@@ -878,15 +872,13 @@ e_ews_folder_utils_remove_as_esource (ESourceRegistry *pregistry,
 	}
 
 	g_list_free_full (sources, g_object_unref);
-	if (!pregistry)
-		g_object_unref (registry);
+	g_object_unref (registry);
 
 	return res;
 }
 
 GList *
-e_ews_folder_utils_get_esources (ESourceRegistry *pregistry,
-				 const gchar *master_hosturl,
+e_ews_folder_utils_get_esources (const gchar *master_hosturl,
 				 const gchar *master_username,
 				 GCancellable *cancellable,
 				 GError **perror)
@@ -894,19 +886,15 @@ e_ews_folder_utils_get_esources (ESourceRegistry *pregistry,
 	ESourceRegistry *registry;
 	GList *all_sources, *esources = NULL;
 
-	registry = pregistry;
-	if (!registry) {
-		registry = e_source_registry_new_sync (cancellable, perror);
-		if (!registry)
-			return NULL;
-	}
+	registry = e_source_registry_new_sync (cancellable, perror);
+	if (!registry)
+		return NULL;
 
 	all_sources = e_source_registry_list_sources (registry, NULL);
 	esources = e_ews_folder_utils_filter_sources_for_account (all_sources, master_hosturl, master_username);
 
 	g_list_free_full (all_sources, g_object_unref);
-	if (!pregistry)
-		g_object_unref (registry);
+	g_object_unref (registry);
 
 	return esources;
 }
