@@ -10,7 +10,7 @@
 #include <libedataserver/libedataserver.h>
 
 #include "e-ews-enums.h"
-#include "e-soap-message.h"
+#include "e-soap-request.h"
 
 G_BEGIN_DECLS
 
@@ -76,9 +76,9 @@ void		e_ews_folder_id_free (EwsFolderId *fid);
 gboolean	e_ews_folder_id_is_equal (const EwsFolderId *a,
 					  const EwsFolderId *b,
 					  gboolean check_change_key);
-void		e_ews_folder_id_append_to_msg (ESoapMessage *msg,
-					       const gchar *email,
-					       const EwsFolderId *fid);
+void		e_ews_folder_id_append_to_request		(ESoapRequest *request,
+								 const gchar *email,
+								 const EwsFolderId *fid);
 gchar *		e_ews_folder_utils_escape_name			(const gchar *folder_name);
 gchar *		e_ews_folder_utils_unescape_name		(const gchar *escaped_folder_name);
 
