@@ -209,12 +209,13 @@ eos_office365_get_authentication_uri (EOAuth2Service *service,
 
 		camel_ews_settings_lock (ews_settings);
 
+		use_oauth2_v2 = camel_ews_settings_get_use_oauth2_v2 (ews_settings);
+
 		if (camel_ews_settings_get_override_oauth2 (ews_settings)) {
 			const gchar *endpoint_host = NULL;
 			const gchar *tenant = NULL;
 			const gchar *uri_path;
 
-			use_oauth2_v2 = camel_ews_settings_get_use_oauth2_v2 (ews_settings);
 			eos_office365_get_endpoint_host_and_tenant_locked (ews_settings, &endpoint_host, &tenant);
 
 			if (use_oauth2_v2)
@@ -253,12 +254,13 @@ eos_office365_get_refresh_uri (EOAuth2Service *service,
 
 		camel_ews_settings_lock (ews_settings);
 
+		use_oauth2_v2 = camel_ews_settings_get_use_oauth2_v2 (ews_settings);
+
 		if (camel_ews_settings_get_override_oauth2 (ews_settings)) {
 			const gchar *endpoint_host = NULL;
 			const gchar *tenant = NULL;
 			const gchar *uri_path;
 
-			use_oauth2_v2 = camel_ews_settings_get_use_oauth2_v2 (ews_settings);
 			eos_office365_get_endpoint_host_and_tenant_locked (ews_settings, &endpoint_host, &tenant);
 
 			if (use_oauth2_v2)
@@ -413,9 +415,7 @@ eos_office365_prepare_authentication_uri_query (EOAuth2Service *service,
 
 	ews_settings = eos_office365_get_camel_settings (source);
 
-	if (ews_settings &&
-	    camel_ews_settings_get_override_oauth2 (ews_settings) &&
-	    camel_ews_settings_get_use_oauth2_v2 (ews_settings))
+	if (ews_settings && camel_ews_settings_get_use_oauth2_v2 (ews_settings))
 		e_oauth2_service_util_set_to_form (uri_query, "scope", eos_office365_get_oauth2_v2_scope (service, source));
 	else
 		e_oauth2_service_util_set_to_form (uri_query, "resource", eos_office365_get_resource_uri (service, source));
@@ -435,9 +435,7 @@ eos_office365_prepare_refresh_token_form (EOAuth2Service *service,
 
 	e_oauth2_service_util_set_to_form (form, "redirect_uri", e_oauth2_service_get_redirect_uri (service, source));
 
-	if (ews_settings &&
-	    camel_ews_settings_get_override_oauth2 (ews_settings) &&
-	    camel_ews_settings_get_use_oauth2_v2 (ews_settings))
+	if (ews_settings && camel_ews_settings_get_use_oauth2_v2 (ews_settings))
 		e_oauth2_service_util_set_to_form (form, "scope", eos_office365_get_oauth2_v2_scope (service, source));
 	else
 		e_oauth2_service_util_set_to_form (form, "resource", eos_office365_get_resource_uri (service, source));
