@@ -335,14 +335,18 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	gtk_grid_set_column_spacing (ews_backend->priv->oauth2_settings_grid, 4);
 	gtk_grid_set_row_spacing (ews_backend->priv->oauth2_settings_grid, 4);
 
+	widget = gtk_check_button_new_with_mnemonic (_("Use _protocol version 2.0 (for school and organization accounts)"));
+	ews_backend->priv->oauth2_v2_check = widget;
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 0, 2, 1);
+
 	container = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, container, 0, 0, 2, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, container, 0, 1, 2, 1);
 
 	widget = gtk_check_button_new_with_mnemonic (_("_Override Office365 OAuth2 settings"));
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
 	ews_backend->priv->oauth2_override_check = widget;
 
-	markup = g_markup_printf_escaped ("(<a href=\"https://wiki.gnome.org/Apps/Evolution/EWS/OAuth2\">%s</a>)", _("Help…"));
+	markup = g_markup_printf_escaped ("(<a href=\"https://gitlab.gnome.org/GNOME/evolution/-/wikis/EWS-OAuth2\">%s</a>)", _("Help…"));
 	widget = gtk_label_new (markup);
 	gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
@@ -352,7 +356,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_label_new_with_mnemonic (_("Application I_D:"));
 	gtk_widget_set_margin_left (widget, 12);
 	gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 1, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 2, 1, 1);
 	label = GTK_LABEL (widget);
 
 	e_binding_bind_property (
@@ -363,7 +367,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_entry_new ();
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_label_set_mnemonic_widget (label, widget);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 1, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 2, 1, 1);
 	ews_backend->priv->oauth2_client_id_entry = widget;
 
 	e_binding_bind_property (
@@ -380,7 +384,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_label_new_with_mnemonic (_("_Tenant ID:"));
 	gtk_widget_set_margin_left (widget, 12);
 	gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 2, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 3, 1, 1);
 	label = GTK_LABEL (widget);
 
 	e_binding_bind_property (
@@ -391,7 +395,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_entry_new ();
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_label_set_mnemonic_widget (label, widget);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 2, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 3, 1, 1);
 	ews_backend->priv->oauth2_tenant_entry = widget;
 
 	e_binding_bind_property (
@@ -408,7 +412,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 		g_strdup_printf (_("Default tenant ID is “%s”"), OFFICE365_TENANT));
 
 	container = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, container, 0, 3, 2, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, container, 0, 4, 2, 1);
 
 	widget = gtk_expander_new_with_mnemonic (_("_Advanced Settings"));
 	gtk_widget_set_margin_left (widget, 12);
@@ -420,7 +424,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 		widget, "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	markup = g_markup_printf_escaped ("(<a href=\"https://wiki.gnome.org/Apps/Evolution/EWS/OAuth2#Alternative_endpoints\">%s</a>)", _("Help…"));
+	markup = g_markup_printf_escaped ("(<a href=\"https://gitlab.gnome.org/GNOME/evolution/-/wikis/EWS-OAuth2#alternative-endpoints\">%s</a>)", _("Help…"));
 	widget = gtk_label_new (markup);
 	gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
@@ -431,7 +435,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_label_new_with_mnemonic (_("_Endpoint host:"));
 	gtk_widget_set_margin_left (widget, 12);
 	gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 4, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 5, 1, 1);
 	label = GTK_LABEL (widget);
 	endpoint_host_label = widget;
 
@@ -443,7 +447,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_entry_new ();
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_label_set_mnemonic_widget (label, widget);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 4, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 5, 1, 1);
 	ews_backend->priv->oauth2_endpoint_host_entry = widget;
 
 	e_binding_bind_property (
@@ -460,7 +464,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_label_new_with_mnemonic (_("Red_irect URI:"));
 	gtk_widget_set_margin_left (widget, 12);
 	gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 5, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 6, 1, 1);
 	label = GTK_LABEL (widget);
 	redirect_uri_label = widget;
 
@@ -472,7 +476,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_entry_new ();
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_label_set_mnemonic_widget (label, widget);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 5, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 6, 1, 1);
 	ews_backend->priv->oauth2_redirect_uri_entry = widget;
 
 	e_binding_bind_property (
@@ -489,7 +493,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_label_new_with_mnemonic (_("Re_source URI:"));
 	gtk_widget_set_margin_left (widget, 12);
 	gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 6, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 0, 7, 1, 1);
 	label = GTK_LABEL (widget);
 	resource_uri_label = widget;
 
@@ -501,7 +505,7 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 	widget = gtk_entry_new ();
 	gtk_widget_set_hexpand (widget, TRUE);
 	gtk_label_set_mnemonic_widget (label, widget);
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 6, 1, 1);
+	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 7, 1, 1);
 	ews_backend->priv->oauth2_resource_uri_entry = widget;
 
 	e_binding_bind_property (
@@ -515,21 +519,11 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 		NULL);
 	g_free (markup);
 
-	widget = gtk_check_button_new_with_mnemonic (_("Use _protocol version 2.0 (for school and organization accounts)"));
-	ews_backend->priv->oauth2_v2_check = widget;
-	gtk_grid_attach (ews_backend->priv->oauth2_settings_grid, widget, 1, 7, 1, 1);
-
-	e_binding_bind_property (
-		ews_backend->priv->oauth2_override_check, "active",
-		widget, "sensitive",
-		G_BINDING_SYNC_CREATE);
-
 	gtk_widget_show_all (GTK_WIDGET (ews_backend->priv->oauth2_settings_grid));
 
 	camel_ews_settings_lock (ews_settings);
 
 	gtk_expander_set_expanded (GTK_EXPANDER (expander),
-		camel_ews_settings_get_use_oauth2_v2 (ews_settings) ||
 		(e_util_strcmp0 (camel_ews_settings_get_oauth2_endpoint_host (ews_settings), NULL) != 0 &&
 		 e_util_strcmp0 (camel_ews_settings_get_oauth2_endpoint_host (ews_settings), OFFICE365_ENDPOINT_HOST) != 0) ||
 		(e_util_strcmp0 (camel_ews_settings_get_oauth2_redirect_uri (ews_settings), NULL) != 0 &&
@@ -573,11 +567,6 @@ mail_config_ews_backend_insert_widgets (EMailConfigServiceBackend *backend,
 		ews_backend->priv->oauth2_resource_uri_entry, "visible",
 		G_BINDING_SYNC_CREATE);
 
-	e_binding_bind_property (
-		expander, "expanded",
-		ews_backend->priv->oauth2_v2_check, "visible",
-		G_BINDING_SYNC_CREATE);
-
 	e_binding_bind_property_full (
 		ews_backend->priv->auth_check, "active-mechanism",
 		ews_backend->priv->oauth2_settings_grid, "visible",
